==> webkit2gtk_2.51.4.orig.tar.xz: webkitgtk-2.51.4/Source/WebCore/rendering/RenderImageResourceStyleImage.h <==
/*
 * Copyright (C) 1999 Lars Knoll <knoll@kde.org>
 * Copyright (C) 1999 Antti Koivisto <koivisto@kde.org>
 * Copyright (C) 2006 Allan Sandfeld Jensen <kde@carewolf.com>
 * Copyright (C) 2006 Samuel Weinig <sam.weinig@gmail.com>
 * Copyright (C) 2004-2025 Apple Inc. All rights reserved.
 * Copyright (C) 2010 Patrick Gansterer <paroga@paroga.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 *
 */

#pragma once

#include <WebCore/RenderImageResource.h>
#include <WebCore/StyleImage.h>
#include <wtf/RefPtr.h>

namespace WebCore {

class RenderElement;

class RenderImageResourceStyleImage final : public RenderImageResource {
    WTF_MAKE_TZONE_OR_ISO_ALLOCATED(RenderImageResourceStyleImage);
    WTF_OVERRIDE_DELETE_FOR_CHECKED_PTR(RenderImageResourceStyleImage);
public:
    explicit RenderImageResourceStyleImage(StyleImage&);

private:
    void initialize(RenderElement&) final;
    void shutdown() final;

    RefPtr<Image> image(const IntSize& = { }) const final;
    bool errorOccurred() const final { return m_styleImage->errorOccurred(); }

    void setContainerContext(const IntSize&, const URL&) final;

    bool imageHasRelativeWidth() const final { return m_styleImage->imageHasRelativeWidth(); }
    bool imageHasRelativeHeight() const final { return m_styleImage->imageHasRelativeHeight(); }

    WrappedImagePtr imagePtr() const final { return m_styleImage->data(); }
    LayoutSize imageSize(float multiplier, CachedImage::SizeType) const final { return LayoutSize(m_styleImage->imageSize(renderer(), multiplier)); }

    const Ref<StyleImage> m_styleImage;
};

} // namespace WebCore

==> webkit2gtk_2.51.90.orig.tar.xz: webkitgtk-2.51.90/Source/WebCore/rendering/RenderImageResourceStyleImage.h <==
/*
 * Copyright (C) 1999 Lars Knoll <knoll@kde.org>
 * Copyright (C) 1999 Antti Koivisto <koivisto@kde.org>
 * Copyright (C) 2006 Allan Sandfeld Jensen <kde@carewolf.com>
 * Copyright (C) 2006 Samuel Weinig <sam.weinig@gmail.com>
 * Copyright (C) 2004-2025 Apple Inc. All rights reserved.
 * Copyright (C) 2010 Patrick Gansterer <paroga@paroga.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 *
 */

#pragma once

#include <WebCore/RenderImageResource.h>
#include <WebCore/StyleImage.h>
#include <wtf/RefPtr.h>

namespace WebCore {

class RenderElement;

class RenderImageResourceStyleImage final : public RenderImageResource {
    WTF_MAKE_TZONE_ALLOCATED(RenderImageResourceStyleImage);
    WTF_OVERRIDE_DELETE_FOR_CHECKED_PTR(RenderImageResourceStyleImage);
public:
    explicit RenderImageResourceStyleImage(StyleImage&);

private:
    void initialize(RenderElement&) final;
    void shutdown() final;

    RefPtr<Image> image(const IntSize& = { }) const final;
    bool errorOccurred() const final { return m_styleImage->errorOccurred(); }

    void setContainerContext(const IntSize&, const URL&) final;

    bool imageHasRelativeWidth() const final { return m_styleImage->imageHasRelativeWidth(); }
    bool imageHasRelativeHeight() const final { return m_styleImage->imageHasRelativeHeight(); }

    WrappedImagePtr imagePtr() const final { return m_styleImage->data(); }
    LayoutSize imageSize(float multiplier, CachedImage::SizeType) const final { return LayoutSize(m_styleImage->imageSize(renderer(), multiplier)); }

    const Ref<StyleImage> m_styleImage;
};

} // namespace WebCore
